#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 mono-traversable-instances
version:              0.1.1.0
visibility:           public
id:                   mono-traversable-instances-0.1.1.0-CrR1N84leQ57r5LT8V4Ut2
key:                  mono-traversable-instances-0.1.1.0-CrR1N84leQ57r5LT8V4Ut2
license:              MIT
maintainer:           michael@fpcomplete.com
author:               Michael Snoyman
homepage:             https://github.com/snoyberg/mono-traversable#readme
synopsis:             Extra typeclass instances for mono-traversable
description:
    See docs and README at <http://www.stackage.org/package/mono-traversable-instance>

category:             Data
abi:                  f7e31e6b30456bc1cbf92f4f486b2f3a
exposed:              True
exposed-modules:      Data.MonoTraversable.Instances
hidden-modules:       Paths_mono_traversable_instances
import-dirs:
    /usr/lib/ghc-8.10.5/site-local/mono-traversable-instances-0.1.1.0

library-dirs:
    /usr/lib/ghc-8.10.5/site-local/mono-traversable-instances-0.1.1.0

dynamic-library-dirs: /usr/lib
data-dir:
    /usr/share/i386-linux-ghc-8.10.5/mono-traversable-instances-0.1.1.0

hs-libraries:         HSmono-traversable-instances-0.1.1.0-CrR1N84leQ57r5LT8V4Ut2
depends:
    base-4.14.2.0 comonad-5.0.8-3VlYiILWTa24txTyM8uxMS
    containers-0.6.4.1 dlist-1.0-2pxhAw6JY91eMk6tw7lC2
    dlist-instances-0.1.1.1-FfIfoy6k0FCCYgFcp9ScpF
    mono-traversable-1.0.15.1-JLGzOoLqJsnDp9BKxi1GUy
    semigroupoids-5.3.5-CXCAmgAqO2AH1F4bh8bCjo transformers-0.5.6.2
    vector-instances-3.4-27mejsZTcBs5ZVWUKghZJg

haddock-interfaces:
    /usr/share/doc/haskell-mono-traversable-instances/html/mono-traversable-instances.haddock

haddock-html:         /usr/share/doc/haskell-mono-traversable-instances/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

